==> zio-aws-appmesh_3-5.17.104.3-sources.jar: zio/aws/appmesh/model/ListVirtualGatewaysRequest.scala <==
package zio.aws.appmesh.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.appmesh.model.primitives.{
  AccountId,
  ResourceName,
  ListVirtualGatewaysLimit
}
import scala.jdk.CollectionConverters.*
final case class ListVirtualGatewaysRequest(
    limit: Option[ListVirtualGatewaysLimit] = None,
    meshName: ResourceName,
    meshOwner: Option[AccountId] = None,
    nextToken: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appmesh.model.ListVirtualGatewaysRequest = {
    import ListVirtualGatewaysRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.ListVirtualGatewaysRequest
      .builder()
      .optionallyWith(
        limit.map(value => ListVirtualGatewaysLimit.unwrap(value): Integer)
      )(_.limit)
      .meshName(ResourceName.unwrap(meshName): java.lang.String)
      .optionallyWith(
        meshOwner.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.meshOwner)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.appmesh.model.ListVirtualGatewaysRequest.ReadOnly =
    zio.aws.appmesh.model.ListVirtualGatewaysRequest.wrap(buildAwsValue())
}
object ListVirtualGatewaysRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appmesh.model.ListVirtualGatewaysRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.ListVirtualGatewaysRequest =
      zio.aws.appmesh.model.ListVirtualGatewaysRequest(
        limit.map(value => value),
        meshName,
        meshOwner.map(value => value),
        nextToken.map(value => value)
      )
    def limit: Option[ListVirtualGatewaysLimit]
    def meshName: ResourceName
    def meshOwner: Option[AccountId]
    def nextToken: Option[String]
    def getLimit: ZIO[Any, AwsError, ListVirtualGatewaysLimit] =
      AwsError.unwrapOptionField("limit", limit)
    def getMeshName: ZIO[Any, Nothing, ResourceName] = ZIO.succeed(meshName)
    def getMeshOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("meshOwner", meshOwner)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.ListVirtualGatewaysRequest
  ) extends zio.aws.appmesh.model.ListVirtualGatewaysRequest.ReadOnly {
    override val limit: Option[ListVirtualGatewaysLimit] = scala
      .Option(impl.limit())
      .map(value =>
        zio.aws.appmesh.model.primitives.ListVirtualGatewaysLimit(value)
      )
    override val meshName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.meshName())
    override val meshOwner: Option[AccountId] = scala
      .Option(impl.meshOwner())
      .map(value => zio.aws.appmesh.model.primitives.AccountId(value))
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.ListVirtualGatewaysRequest
  ): zio.aws.appmesh.model.ListVirtualGatewaysRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-appmesh_3-5.17.203.1-sources.jar: zio/aws/appmesh/model/ListVirtualGatewaysRequest.scala <==
package zio.aws.appmesh.model
import zio.aws.appmesh.model.primitives.{
  AccountId,
  ResourceName,
  ListVirtualGatewaysLimit
}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class ListVirtualGatewaysRequest(
    limit: Optional[ListVirtualGatewaysLimit] = Optional.Absent,
    meshName: ResourceName,
    meshOwner: Optional[AccountId] = Optional.Absent,
    nextToken: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appmesh.model.ListVirtualGatewaysRequest = {
    import ListVirtualGatewaysRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.ListVirtualGatewaysRequest
      .builder()
      .optionallyWith(
        limit.map(value => ListVirtualGatewaysLimit.unwrap(value): Integer)
      )(_.limit)
      .meshName(ResourceName.unwrap(meshName): java.lang.String)
      .optionallyWith(
        meshOwner.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.meshOwner)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.appmesh.model.ListVirtualGatewaysRequest.ReadOnly =
    zio.aws.appmesh.model.ListVirtualGatewaysRequest.wrap(buildAwsValue())
}
object ListVirtualGatewaysRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appmesh.model.ListVirtualGatewaysRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.ListVirtualGatewaysRequest =
      zio.aws.appmesh.model.ListVirtualGatewaysRequest(
        limit.map(value => value),
        meshName,
        meshOwner.map(value => value),
        nextToken.map(value => value)
      )
    def limit: Optional[ListVirtualGatewaysLimit]
    def meshName: ResourceName
    def meshOwner: Optional[AccountId]
    def nextToken: Optional[String]
    def getLimit: ZIO[Any, AwsError, ListVirtualGatewaysLimit] =
      AwsError.unwrapOptionField("limit", limit)
    def getMeshName: ZIO[Any, Nothing, ResourceName] = ZIO.succeed(meshName)
    def getMeshOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("meshOwner", meshOwner)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.ListVirtualGatewaysRequest
  ) extends zio.aws.appmesh.model.ListVirtualGatewaysRequest.ReadOnly {
    override val limit: Optional[ListVirtualGatewaysLimit] =
      zio.aws.core.internal
        .optionalFromNullable(impl.limit())
        .map(value =>
          zio.aws.appmesh.model.primitives.ListVirtualGatewaysLimit(value)
        )
    override val meshName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.meshName())
    override val meshOwner: Optional[AccountId] = zio.aws.core.internal
      .optionalFromNullable(impl.meshOwner())
      .map(value => zio.aws.appmesh.model.primitives.AccountId(value))
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.ListVirtualGatewaysRequest
  ): zio.aws.appmesh.model.ListVirtualGatewaysRequest.ReadOnly = new Wrapper(
    impl
  )
}
